==> webview_flutter_plus-0.4.3.tar.gz: lib/src/controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:webview_flutter_plus/src/server.dart';

class WebViewControllerPlus extends WebViewController {
  final WebViewServer _server = WebViewServer();

  get server => _server;

  WebViewControllerPlus({
    super.onPermissionRequest,
  });

  /// Return the height of [WebViewWidget]
  Future<Object> getWebViewHeight() async {
    String getHeightScript = r"""
        getWebviewHeight();
        function getWebviewHeight() {
            var element = document.body;
            var height = element.offsetHeight,
                style = window.getComputedStyle(element)
            return ['top', 'bottom']
                .map(function (side) {
                    return parseInt(style["margin-" + side]);
                })
                .reduce(function (total, side) {
                    return total + side;
                }, height)
              }
              
              """;
    return await super.runJavaScriptReturningResult(getHeightScript);
  }

  /// Load assets on server
  Future<void> loadAssetServer(
    String uri, {
    LoadRequestMethod method = LoadRequestMethod.get,
    Map<String, String> headers = const <String, String>{},
    Uint8List? body,
  }) async {
    var port = await _server.start();
    return super.loadRequest(Uri.parse('http://localhost:$port/$uri'),
        headers: headers, body: body, method: method);
  }
}

==> webview_flutter_plus-0.4.4.tar.gz: lib/src/controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:webview_flutter_plus/src/server.dart';

class WebViewControllerPlus extends WebViewController {
  final WebViewServer _server = WebViewServer();

  get server => _server;

  WebViewControllerPlus({
    super.onPermissionRequest,
  });

  /// Return the height of [WebViewWidget]
  Future<Object> getWebViewHeight() async {
    String getHeightScript = r"""getWebviewHeight();
        function getWebviewHeight() {
            var element = document.body;
            var height = element.offsetHeight,
                style = window.getComputedStyle(element)
            return ['top', 'bottom']
                .map(function (side) {
                    return parseInt(style["margin-" + side]);
                })
                .reduce(function (total, side) {
                    return total + side;
                }, height)
              }""";
    return await super.runJavaScriptReturningResult(getHeightScript);
  }

  /// Event fires when the entire page (including all its resources like images, scripts, and stylesheets) has finished loading.
  Future<Object> onLoaded(Function(String message) onLoadedCallback) async {
    super.addJavaScriptChannel("OnLoadedCallback", onMessageReceived: (msg) {
      onLoadedCallback(msg.message);
    });
    return await super.runJavaScriptReturningResult(
        """window.onload = function () {OnLoadedCallback.postMessage("Page Loaded...!");}""");
  }

  /// Load assets on server
  Future<void> loadFlutterAssetServer(
    String uri, {
    LoadRequestMethod method = LoadRequestMethod.get,
    Map<String, String> headers = const <String, String>{},
    Uint8List? body,
  }) async {
    var port = await _server.start();
    return super.loadRequest(Uri.parse('http://localhost:$port/$uri'),
        headers: headers, body: body, method: method);
  }
}
